"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CameraSubscriber = void 0;
const IChannelInterfaces_1 = require("./interfaces/IChannelInterfaces");
const Subscriber_1 = require("./Subscriber");
const VolumeDetector_1 = require("./workers/VolumeDetector");
class CameraSubscriber extends Subscriber_1.Subscriber {
    constructor(id, loggerLevel) {
        super(id, loggerLevel);
        this.logger.debug('Camera subscriber created');
    }
    init(createAudioTrack, createVideoTrack) {
        return __awaiter(this, void 0, void 0, function* () {
            // Set RTCPeerConnection to only receive streams
            if (createAudioTrack) {
                const transceiver = this.conn.addTransceiver('audio', {
                    direction: 'recvonly'
                });
                this.logger.debug('Audio transceiver added to Subscriber RTCPeerConnection', transceiver);
                if (VolumeDetector_1.VolumeDetector.isVolumeDetectorSupported) {
                    this._volumeDetector = new VolumeDetector_1.VolumeDetector(500, this.mediaStream);
                    this._volumeDetectorSubscription = this._volumeDetector.emitter$.subscribe((volume) => {
                        this.emitter.next({
                            type: IChannelInterfaces_1.EmittedDataType.Volume,
                            data: { channelId: this.id, volume: volume }
                        });
                    });
                }
                else {
                    console.log('This browser does not support volume detection feature.');
                }
            }
            if (createVideoTrack) {
                const transceiver = this.conn.addTransceiver('video', {
                    direction: 'recvonly'
                });
                this.logger.debug('Video transceiver added to Subscriber RTCPeerConnection', transceiver);
            }
        });
    }
    dispose() {
        const _super = Object.create(null, {
            dispose: { get: () => super.dispose }
        });
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            (_a = this._volumeDetectorSubscription) === null || _a === void 0 ? void 0 : _a.unsubscribe();
            yield ((_b = this._volumeDetector) === null || _b === void 0 ? void 0 : _b.dispose());
            yield _super.dispose.call(this);
        });
    }
    onTrack(event) {
        const _super = Object.create(null, {
            onTrack: { get: () => super.onTrack }
        });
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            yield _super.onTrack.call(this, event);
            if (event.track.kind === 'audio') {
                yield ((_a = this._volumeDetector) === null || _a === void 0 ? void 0 : _a.start());
            }
        });
    }
}
exports.CameraSubscriber = CameraSubscriber;
