"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileBox = void 0;
const uuid_1 = require("uuid");
const Logger_1 = require("./Logger");
class FileBox {
    constructor(loggerLevel) {
        this._chunkSize = 500000;
        this._files = [];
        this._logger = new Logger_1.Logger(loggerLevel);
    }
    get chuckSize() {
        return this._chunkSize;
    }
    add(file, messageId) {
        return __awaiter(this, void 0, void 0, function* () {
            const buffer = yield file.arrayBuffer();
            const fileId = (0, uuid_1.v4)();
            this._files.push({ id: fileId, messageId: messageId, buffer: buffer });
            return fileId;
        });
    }
    getChunk(fileId, chunkNumber) {
        const file = this._files.find(f => f.id === fileId);
        if (!file) {
            throw new Error(`File not found. File Id: ${fileId}`);
        }
        const place = chunkNumber * this._chunkSize;
        return file.buffer.slice(place, place + Math.min(this._chunkSize, file.buffer.byteLength - place));
    }
    remove(fileId) {
        const file = this._files.find(f => f.id === fileId);
        if (file) {
            this._files.splice(this._files.indexOf(file), 1);
            this._logger.debug('File removed. FileId: ', fileId);
        }
    }
    removeByMessage(messageId) {
        const files = this._files.filter(f => f.messageId === messageId);
        files.forEach(f => this.remove(f.id));
    }
    some(fileId) {
        return this._files.some(f => f.id === fileId);
    }
}
exports.FileBox = FileBox;
