/**
 * The minimum level of log messages to be printed to the console.\
 * \
 * See also: [[Session.constructor | Session]]
 */
declare enum LoggerLevel {
    /**
     * All messages are printed to the console.
     */
    Verbose = 0,
    /**
     * Debug, Info, Warn and Error messages are printed to the console.
     */
    Debug = 1,
    /**
     * Info, Warn and Error messages are printed to the console.
     */
    Info = 2,
    /**
     * Warn and Error messages are printed to the console.
     */
    Warn = 3,
    /**
     * Only Error messages are printed to the console.
     */
    Error = 4,
    /**
     * No messages are printed to the console.
     */
    None = 5
}
/**
 * @ignore
 */
declare class Logger {
    private _id;
    private _level;
    get level(): LoggerLevel;
    constructor(level: LoggerLevel, id?: string);
    private buildMessage;
    debug(message?: any, ...optionalParams: any[]): void;
    error(message?: any, ...optionalParams: any[]): void;
    info(message?: any, ...optionalParams: any[]): void;
    verbose(message?: any, ...optionalParams: any[]): void;
    warn(message?: any, ...optionalParams: any[]): void;
}
export { Logger, LoggerLevel };
