"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoggerLevel = exports.Logger = void 0;
/**
 * The minimum level of log messages to be printed to the console.\
 * \
 * See also: [[Session.constructor | Session]]
 */
var LoggerLevel;
(function (LoggerLevel) {
    /**
     * All messages are printed to the console.
     */
    LoggerLevel[LoggerLevel["Verbose"] = 0] = "Verbose";
    /**
     * Debug, Info, Warn and Error messages are printed to the console.
     */
    LoggerLevel[LoggerLevel["Debug"] = 1] = "Debug";
    /**
     * Info, Warn and Error messages are printed to the console.
     */
    LoggerLevel[LoggerLevel["Info"] = 2] = "Info";
    /**
     * Warn and Error messages are printed to the console.
     */
    LoggerLevel[LoggerLevel["Warn"] = 3] = "Warn";
    /**
     * Only Error messages are printed to the console.
     */
    LoggerLevel[LoggerLevel["Error"] = 4] = "Error";
    /**
     * No messages are printed to the console.
     */
    LoggerLevel[LoggerLevel["None"] = 5] = "None";
})(LoggerLevel || (LoggerLevel = {}));
exports.LoggerLevel = LoggerLevel;
/**
 * @ignore
 */
class Logger {
    constructor(level, id) {
        this._id = id;
        this._level = level;
    }
    get level() {
        return this._level;
    }
    buildMessage(message) {
        return this._id ? `${this._id}: ${message}` : message;
    }
    debug(message, ...optionalParams) {
        if (this._level <= LoggerLevel.Debug) {
            console.log(this.buildMessage(message), ...optionalParams);
        }
    }
    error(message, ...optionalParams) {
        if (this._level <= LoggerLevel.Error) {
            console.error(this.buildMessage(message), ...optionalParams);
        }
    }
    info(message, ...optionalParams) {
        if (this._level <= LoggerLevel.Info) {
            console.log(this.buildMessage(message), ...optionalParams);
        }
    }
    verbose(message, ...optionalParams) {
        if (this._level <= LoggerLevel.Verbose) {
            console.log(this.buildMessage(message), ...optionalParams);
        }
    }
    warn(message, ...optionalParams) {
        if (this._level <= LoggerLevel.Warn) {
            console.warn(this.buildMessage(message), ...optionalParams);
        }
    }
}
exports.Logger = Logger;
