"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScreenPublisher = void 0;
const Channel_1 = require("./Channel");
const IChannelInterfaces_1 = require("./interfaces/IChannelInterfaces");
class ScreenPublisher extends Channel_1.Channel {
    constructor(id, loggerLevel) {
        super(id, loggerLevel);
        // Handle the need of a new negotiation
        // Occurs when addTrack is called and when connection status changes
        this.conn.onnegotiationneeded = () => __awaiter(this, void 0, void 0, function* () { return yield this.onNegotiationNeeded(); });
        this.logger.debug('Screen publisher created');
    }
    onNegotiationNeeded() {
        return __awaiter(this, void 0, void 0, function* () {
            this.emitter.next({
                type: IChannelInterfaces_1.EmittedDataType.ScreenPublisherOffer,
                data: {
                    id: this.id,
                    offer: yield this.createOffer()
                }
            });
        });
    }
    init() {
        return __awaiter(this, void 0, void 0, function* () {
            const stream = yield navigator.mediaDevices.getDisplayMedia();
            const track = stream.getTracks()[0];
            track.onended = () => {
                this.emitter.next({
                    type: IChannelInterfaces_1.EmittedDataType.ScreenSharingStopped,
                    data: {
                        publisherId: this.id
                    }
                });
            };
            this.stream.addTrack(track);
            const transceiver = this.conn.addTransceiver(track, {
                direction: 'sendonly'
            });
            this.logger.debug('Transceiver added to Publisher RTCPeerConnection', transceiver);
        });
    }
}
exports.ScreenPublisher = ScreenPublisher;
