"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SocketIOSignaler = void 0;
const socket_io_client_1 = require("socket.io-client");
const rxjs_1 = require("rxjs");
const ISignaler_1 = require("./interfaces/ISignaler");
class SocketIOSignaler {
    constructor(webSocketUrl, sessionId, nickname) {
        this._socket = (0, socket_io_client_1.io)(webSocketUrl, {
            query: {
                id: sessionId,
                nickname: nickname,
            },
            withCredentials: false
        });
        this.emitter = new rxjs_1.Subject();
        this._socket.on('answer', (params) => this.emitter.next({ type: ISignaler_1.SignalType.Answer, params: params }));
        this._socket.on('connect', () => this.emitter.next({ type: ISignaler_1.SignalType.Connect }));
        this._socket.on('connect_error', (error) => console.error(error));
        this._socket.on('delete-message', (params) => this.emitter.next({ type: ISignaler_1.SignalType.DeleteMessage, params: params }));
        this._socket.on('edit-message', (params) => this.emitter.next({ type: ISignaler_1.SignalType.EditMessage, params: params }));
        this._socket.on('error-message', (params) => this.emitter.next({ type: ISignaler_1.SignalType.Error, params: params }));
        this._socket.on('file-chunk', (params) => this.emitter.next({ type: ISignaler_1.SignalType.FileChunk, params: params }));
        this._socket.on('file-progress', (params) => this.emitter.next({ type: ISignaler_1.SignalType.FileProgress, params: params }));
        this._socket.on('new-ice-candidate', (params) => this.emitter.next({ type: ISignaler_1.SignalType.NewIceCandidate, params: params }));
        this._socket.on('new-message', (params) => this.emitter.next({ type: ISignaler_1.SignalType.NewMessage, params: params }));
        this._socket.on('new-participant', (params) => this.emitter.next({ type: ISignaler_1.SignalType.NewParticipant, params: params }));
        this._socket.on('new-publisher', (params) => this.emitter.next({ type: ISignaler_1.SignalType.NewPublisher, params: params }));
        this._socket.on('publisher-status', (params) => this.emitter.next({ type: ISignaler_1.SignalType.PublisherStatus, params: params }));
        this._socket.on('rec-started', (params) => this.emitter.next({ type: ISignaler_1.SignalType.RecStarted, params: params }));
        this._socket.on('rec-stopped', () => this.emitter.next({ type: ISignaler_1.SignalType.RecStopped }));
        this._socket.on('remove-participant', (params) => this.emitter.next({ type: ISignaler_1.SignalType.RemoveParticipant, params: params }));
        this._socket.on('remove-publisher', (params) => this.emitter.next({ type: ISignaler_1.SignalType.RemovePublisher, params: params }));
        this._socket.on('session-ended', (params) => this.emitter.next({ type: ISignaler_1.SignalType.SessionEnded, params: params }));
        this._socket.on('typing', (params) => this.emitter.next({ type: ISignaler_1.SignalType.Typing, params: params }));
        this._socket.on('welcome', (params) => this.emitter.next({ type: ISignaler_1.SignalType.Welcome, params: params }));
    }
    get id() {
        var _a;
        return (_a = this._socket) === null || _a === void 0 ? void 0 : _a.id;
    }
    dispose() {
        this._socket.close();
    }
    send(type, params) {
        this._socket.emit(type, params);
    }
}
exports.SocketIOSignaler = SocketIOSignaler;
