/**
 * The type of data emitted by [[Session]].
 */
export declare enum SessionEmittedDataType {
    /**
     * Emitted after toggling audio (enable/disable own microphone).\
     * This can be done by calling [[toggleAudio]] method.\
     * \
     * See also: [[IAudioMutedChanged]].
     */
    AudioMutedChanged = 0,
    /**
   * Emitted when a publisher video track has been blurred.\
   * \
   * See also: [[IBlurStarted]].
   */
    BlurStarted = 1,
    /**
   * Emitted when a publisher video track blur has been removed.\
   * \
   * See also: [[IBlurStopped]].
   */
    BlurStopped = 2,
    /**
   * Emitted when a publisher video track has been masked.\
   * \
   * See also: [[IMaskStarted]].
   */
    MaskStarted = 3,
    /**
   * Emitted when a publisher video track mask has been removed.\
   * \
   * See also: [[IMaskStopped]].
   */
    MaskStopped = 4,
    /**
     * Emitted when a message has been deleted.\
     * \
     * See also: [[IDeleteMessage]].
     */
    DeleteMessage = 5,
    /**
     * Emitted when a message has been edited.\
     * \
     * See also: [[IEditMessage]].
     */
    EditMessage = 6,
    /**
     * Emitted while uploading a file, showing the progress of the upload.\
     * \
     * See also: [[IFileProgress]].
     */
    FileProgress = 7,
    /**
     * Emitted after the creation of session's own participant.\
     * This happens automatically after calling [[joinMeeting]] method.\
     * \
     * See also: [[INewParticipant]].
     */
    Me = 8,
    /**
     * Recurrently emitted for each publisher having an audio track.
     * \
     * See also: [[IMyVolume]].
     */
    MyVolume = 9,
    /**
     * Emitted when a new text message is received.\
     * \
     * See also: [[INewMessage]].
     */
    NewMessage = 10,
    /**
     * Emitted when a remote participant joins the session.\
     * \
     * See also: [[INewParticipant]].
     */
    NewParticipant = 11,
    /**
     * Emitted after own stream is published.\
     * This happens automatically after calling [[joinMeeting]] method and after enabling screensharing using [[toggleScreensharing]] method.\
     * \
     * See also: [[INewPublisher]].
     */
    NewPublisher = 12,
    /**
     * Emitted when a remote participant adds a stream.\
     * \
     * See also: [[INewSubscriber]].
     */
    NewSubscriber = 13,
    /**
     * Emitted when the recording starts.\
     * \
     * See also: [[IRecStarted]].
     */
    RecStarted = 14,
    /**
     * Emitted when the recording stops.
     */
    RecStopped = 15,
    /**
     * Emitted when a remote participant leaves the session.\
     * \
     * See also: [[IRemoveParticipant]].
     */
    RemoveParticipant = 16,
    /**
     * Emitted when own stream is removed.\
     * This happens after disabling screensharing using [[toggleScreensharing]] method.
     */
    RemovePublisher = 17,
    /**
     * Emitted when a remote participant removes a stream.\
     * \
     * See also: [[IRemoveSubscriber]].
     */
    RemoveSubscriber = 18,
    /**
     * Emitted when the session ends.\
     * \
     * See also: [[ISessionEnded]].
     */
    SessionEnded = 19,
    /**
     * Emitted when an error occurs.
     */
    Error = 20,
    /**
     * Emitted when a subscriber status changed.
     */
    SubscriberStatus = 21,
    /**
     * Recurrently emitted for each subscriber having an audio track.
     * \
     * See also: [[IParticipantVolume]].
     */
    ParticipantVolume = 22,
    /**
     * Emitted when a participant starts or stops typing.
     * \
     * See also: [[ITyping]].
     */
    Typing = 23,
    /**
     * Emitted after successfully toggling video (enable/disable own camera).\
     * This can be done by calling [[toggleVideo]] method.\
     * \
     * See also: [[IVideoHiddenChanged]].
     */
    VideoHiddenChanged = 24,
    /**
     * Emitted when the session websocket connection is established.\
     * \
     * See also: [[IWebSocketConnected]].
     */
    WebSocketConnected = 25,
    /**
     * Emitted after successfully join the session.\
     * \
     * See also: [[IWelcome]].
     */
    Welcome = 26
}
