"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SessionEmittedDataType = void 0;
/**
 * The type of data emitted by [[Session]].
 */
var SessionEmittedDataType;
(function (SessionEmittedDataType) {
    /**
     * Emitted after toggling audio (enable/disable own microphone).\
     * This can be done by calling [[toggleAudio]] method.\
     * \
     * See also: [[IAudioMutedChanged]].
     */
    SessionEmittedDataType[SessionEmittedDataType["AudioMutedChanged"] = 0] = "AudioMutedChanged";
    /**
   * Emitted when a publisher video track has been blurred.\
   * \
   * See also: [[IBlurStarted]].
   */
    SessionEmittedDataType[SessionEmittedDataType["BlurStarted"] = 1] = "BlurStarted";
    /**
   * Emitted when a publisher video track blur has been removed.\
   * \
   * See also: [[IBlurStopped]].
   */
    SessionEmittedDataType[SessionEmittedDataType["BlurStopped"] = 2] = "BlurStopped";
    /**
   * Emitted when a publisher video track has been masked.\
   * \
   * See also: [[IMaskStarted]].
   */
    SessionEmittedDataType[SessionEmittedDataType["MaskStarted"] = 3] = "MaskStarted";
    /**
   * Emitted when a publisher video track mask has been removed.\
   * \
   * See also: [[IMaskStopped]].
   */
    SessionEmittedDataType[SessionEmittedDataType["MaskStopped"] = 4] = "MaskStopped";
    /**
     * Emitted when a message has been deleted.\
     * \
     * See also: [[IDeleteMessage]].
     */
    SessionEmittedDataType[SessionEmittedDataType["DeleteMessage"] = 5] = "DeleteMessage";
    /**
     * Emitted when a message has been edited.\
     * \
     * See also: [[IEditMessage]].
     */
    SessionEmittedDataType[SessionEmittedDataType["EditMessage"] = 6] = "EditMessage";
    /**
     * Emitted while uploading a file, showing the progress of the upload.\
     * \
     * See also: [[IFileProgress]].
     */
    SessionEmittedDataType[SessionEmittedDataType["FileProgress"] = 7] = "FileProgress";
    /**
     * Emitted after the creation of session's own participant.\
     * This happens automatically after calling [[joinMeeting]] method.\
     * \
     * See also: [[INewParticipant]].
     */
    SessionEmittedDataType[SessionEmittedDataType["Me"] = 8] = "Me";
    /**
     * Recurrently emitted for each publisher having an audio track.
     * \
     * See also: [[IMyVolume]].
     */
    SessionEmittedDataType[SessionEmittedDataType["MyVolume"] = 9] = "MyVolume";
    /**
     * Emitted when a new text message is received.\
     * \
     * See also: [[INewMessage]].
     */
    SessionEmittedDataType[SessionEmittedDataType["NewMessage"] = 10] = "NewMessage";
    /**
     * Emitted when a remote participant joins the session.\
     * \
     * See also: [[INewParticipant]].
     */
    SessionEmittedDataType[SessionEmittedDataType["NewParticipant"] = 11] = "NewParticipant";
    /**
     * Emitted after own stream is published.\
     * This happens automatically after calling [[joinMeeting]] method and after enabling screensharing using [[toggleScreensharing]] method.\
     * \
     * See also: [[INewPublisher]].
     */
    SessionEmittedDataType[SessionEmittedDataType["NewPublisher"] = 12] = "NewPublisher";
    /**
     * Emitted when a remote participant adds a stream.\
     * \
     * See also: [[INewSubscriber]].
     */
    SessionEmittedDataType[SessionEmittedDataType["NewSubscriber"] = 13] = "NewSubscriber";
    /**
     * Emitted when the recording starts.\
     * \
     * See also: [[IRecStarted]].
     */
    SessionEmittedDataType[SessionEmittedDataType["RecStarted"] = 14] = "RecStarted";
    /**
     * Emitted when the recording stops.
     */
    SessionEmittedDataType[SessionEmittedDataType["RecStopped"] = 15] = "RecStopped";
    /**
     * Emitted when a remote participant leaves the session.\
     * \
     * See also: [[IRemoveParticipant]].
     */
    SessionEmittedDataType[SessionEmittedDataType["RemoveParticipant"] = 16] = "RemoveParticipant";
    /**
     * Emitted when own stream is removed.\
     * This happens after disabling screensharing using [[toggleScreensharing]] method.
     */
    SessionEmittedDataType[SessionEmittedDataType["RemovePublisher"] = 17] = "RemovePublisher";
    /**
     * Emitted when a remote participant removes a stream.\
     * \
     * See also: [[IRemoveSubscriber]].
     */
    SessionEmittedDataType[SessionEmittedDataType["RemoveSubscriber"] = 18] = "RemoveSubscriber";
    /**
     * Emitted when the session ends.\
     * \
     * See also: [[ISessionEnded]].
     */
    SessionEmittedDataType[SessionEmittedDataType["SessionEnded"] = 19] = "SessionEnded";
    /**
     * Emitted when an error occurs.
     */
    SessionEmittedDataType[SessionEmittedDataType["Error"] = 20] = "Error";
    /**
     * Emitted when a subscriber status changed.
     */
    SessionEmittedDataType[SessionEmittedDataType["SubscriberStatus"] = 21] = "SubscriberStatus";
    /**
     * Recurrently emitted for each subscriber having an audio track.
     * \
     * See also: [[IParticipantVolume]].
     */
    SessionEmittedDataType[SessionEmittedDataType["ParticipantVolume"] = 22] = "ParticipantVolume";
    /**
     * Emitted when a participant starts or stops typing.
     * \
     * See also: [[ITyping]].
     */
    SessionEmittedDataType[SessionEmittedDataType["Typing"] = 23] = "Typing";
    /**
     * Emitted after successfully toggling video (enable/disable own camera).\
     * This can be done by calling [[toggleVideo]] method.\
     * \
     * See also: [[IVideoHiddenChanged]].
     */
    SessionEmittedDataType[SessionEmittedDataType["VideoHiddenChanged"] = 24] = "VideoHiddenChanged";
    /**
     * Emitted when the session websocket connection is established.\
     * \
     * See also: [[IWebSocketConnected]].
     */
    SessionEmittedDataType[SessionEmittedDataType["WebSocketConnected"] = 25] = "WebSocketConnected";
    /**
     * Emitted after successfully join the session.\
     * \
     * See also: [[IWelcome]].
     */
    SessionEmittedDataType[SessionEmittedDataType["Welcome"] = 26] = "Welcome";
})(SessionEmittedDataType = exports.SessionEmittedDataType || (exports.SessionEmittedDataType = {}));
