import { Subject } from "rxjs";
import { ErrorCode } from "../enums/ErrorCode";
import { Reason } from "../enums/Reason";
import { StreamKind } from "../enums/StreamKind";
export declare enum AttachmentType {
    File = "file"
}
export declare enum SignalType {
    Answer = 0,
    Connect = 1,
    DeleteMessage = 2,
    EditMessage = 3,
    Error = 4,
    FileChunk = 5,
    FileProgress = 6,
    NewIceCandidate = 7,
    NewMessage = 8,
    NewParticipant = 9,
    NewPublisher = 10,
    PublisherStatus = 11,
    RecStarted = 12,
    RecStopped = 13,
    RemoveParticipant = 14,
    RemovePublisher = 15,
    SessionEnded = 16,
    Typing = 17,
    Welcome = 18
}
export interface IAnswerParams {
    id: string;
    participantId: string;
    answer: string;
}
export interface IAttachments {
    type: AttachmentType;
    data: IFile[];
}
export interface IDeleteMessageParams {
    id: string;
}
export interface IEditMessageParams {
    id: string;
    text: string;
    mentions?: IMention[];
}
export interface IErrorParams {
    code: ErrorCode;
    message: string;
    metadata?: any;
}
export interface IFile {
    id: string;
    name: string;
    size: number;
    url: string;
}
export interface IFileChunkParams {
    id: string;
    messageId: string;
    chunkNumber: number;
}
export interface IFileProgressParams {
    id: string;
    messageId: string;
    progress: number;
}
export interface IMention {
    start: number;
    length: number;
    participantId: string;
}
export interface INewIceCandidateParams {
    id: string;
    participantId: string;
    candidate: RTCIceCandidateInit;
}
export interface INewMessageParams {
    id: string;
    participantId: string;
    nickname: string;
    text?: string;
    attachments?: IAttachments;
    replyId?: string;
    mentions?: IMention[];
    sentAt: string;
}
export interface INewParticipantParams {
    id: string;
    nickname: string;
}
export interface INewPublisherParams {
    id: string;
    participantId: string;
    isAudioPresent: boolean;
    isVideoPresent: boolean;
    isAudioMuted: boolean;
    isVideoHidden: boolean;
    streamKind: StreamKind;
}
export interface IPublisherStatusParams {
    id: string;
    isAudioMuted: boolean;
    isVideoHidden: boolean;
    participantId: string;
    streamKind: StreamKind;
}
export interface IRecStartedParams {
    id: string;
}
export interface IRemoveParticipantParams {
    id: string;
}
export interface IRemovePublisherParams {
    id: string;
    participantId: string;
}
export interface ISessionEndedParams {
    reason: {
        code: Reason;
        description: string;
    };
}
export interface ISignal {
    type: SignalType;
    params?: IAnswerParams | IErrorParams | IFileChunkParams | INewIceCandidateParams | INewParticipantParams | IRemoveParticipantParams | ISessionEndedParams | ITypingParams;
}
export interface ISignaler {
    id: string;
    emitter: Subject<ISignal>;
    send: (type: string, params: any) => void;
}
export interface ITypingParams {
    participantId: string;
    typing: boolean;
}
export interface IWelcomeParams {
    id: string;
    topic: string;
    capabilities: {
        audio: boolean;
        video: boolean;
        chat: boolean;
    };
    recordingId: string;
    feedback: boolean;
    guestRedirectionUrl?: string;
    participantId: string;
}
