"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.VolumeDetector = void 0;
const rxjs_1 = require("rxjs");
const VolumeDetectorProcessor_1 = require("./processors/VolumeDetectorProcessor");
const AudioContext = window.AudioContext;
class VolumeDetector {
    constructor(interval, stream) {
        this._interval = interval;
        this._stream = stream;
        this._volume = 0;
        this._emitter$ = new rxjs_1.Subject();
        this._audioContext = new AudioContext();
    }
    get emitter$() {
        return this._emitter$.asObservable();
    }
    static get isVolumeDetectorSupported() {
        return !!AudioContext && !!new AudioContext().audioWorklet;
    }
    start() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield this.loadProcessor();
                this._source = this._audioContext.createMediaStreamSource(this._stream);
                this._node = new AudioWorkletNode(this._audioContext, 'volume-detector');
                this._node.port.onmessage = event => {
                    this._volume = Math.floor(event.data.volume * 10000);
                };
                this._source.connect(this._node).connect(this._audioContext.destination);
                this._intervalSubscription = (0, rxjs_1.interval)(this._interval).subscribe(() => {
                    this._emitter$.next(this._volume);
                });
            }
            catch (error) {
                console.error(error);
            }
        });
    }
    loadProcessor() {
        return __awaiter(this, void 0, void 0, function* () {
            const blob = new Blob([VolumeDetectorProcessor_1.processor], { type: "application/javascript" });
            var url = URL.createObjectURL(blob);
            yield this._audioContext.audioWorklet.addModule(url);
        });
    }
    dispose() {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            this._intervalSubscription.unsubscribe();
            (_a = this._node) === null || _a === void 0 ? void 0 : _a.disconnect();
            (_b = this._source) === null || _b === void 0 ? void 0 : _b.disconnect();
            yield this._audioContext.close();
        });
    }
}
exports.VolumeDetector = VolumeDetector;
