import { Logger, LoggerLevel } from '../src/Logger';

describe('Logger', () => {
  beforeEach(() => {
    jest.clearAllMocks();
  });

  it.each`
    loggerLevel
    ${LoggerLevel.None}
    ${LoggerLevel.Debug}
    ${LoggerLevel.Info}
    ${LoggerLevel.Warn}
    ${LoggerLevel.Error}
  `('should return Logger level', ({ loggerLevel }) => {
    const logger = new Logger(loggerLevel);
    const returnedLoggerLevel = logger.level;
    expect(returnedLoggerLevel).toEqual(loggerLevel);
  });

  it.each`
    loggerLevel           | id        | expectedCalledTimes
    ${LoggerLevel.None}   | ${null}   | ${1}
    ${LoggerLevel.None}   | ${'123'}  | ${1}
    ${LoggerLevel.Debug}  | ${null}   | ${1}
    ${LoggerLevel.Debug}  | ${'123'}  | ${1}
    ${LoggerLevel.Info}   | ${null}   | ${0}
    ${LoggerLevel.Info}   | ${'123'}  | ${0}
    ${LoggerLevel.Warn}   | ${null}   | ${0}
    ${LoggerLevel.Warn}   | ${'123'}  | ${0}
    ${LoggerLevel.Error}  | ${null}   | ${0}
    ${LoggerLevel.Error}  | ${'123'}  | ${0}
  `('should print to the console if LoggerLevel is equal or lesser than 1 (LoggerLevel.Debug) a message that starts with the specified id only if provided', ({ loggerLevel, id, expectedCalledTimes }) => {
    const messageToPrint = 'Debug message';
    const logger = new Logger(loggerLevel, id);
    console.log = jest.fn();
    logger.debug(messageToPrint);
    expect(console.log).toHaveBeenCalledTimes(expectedCalledTimes);
    if (expectedCalledTimes === 1) {
      const message = id ? `${id}: ${messageToPrint}` : messageToPrint;
      expect(console.log).toHaveBeenCalledWith(message);
    }
  });

  it.each`
    loggerLevel           | id        | expectedCalledTimes
    ${LoggerLevel.None}   | ${null}   | ${1}
    ${LoggerLevel.None}   | ${'123'}  | ${1}
    ${LoggerLevel.Debug}  | ${null}   | ${1}
    ${LoggerLevel.Debug}  | ${'123'}  | ${1}
    ${LoggerLevel.Info}   | ${null}   | ${1}
    ${LoggerLevel.Info}   | ${'123'}  | ${1}
    ${LoggerLevel.Warn}   | ${null}   | ${0}
    ${LoggerLevel.Warn}   | ${'123'}  | ${0}
    ${LoggerLevel.Error}  | ${null}   | ${0}
    ${LoggerLevel.Error}  | ${'123'}  | ${0}
  `('should print to the console if LoggerLevel is equal or lesser than 2 (LoggerLevel.Info) a message that starts with the specified id only if provided', ({ loggerLevel, id, expectedCalledTimes }) => {
    const messageToPrint = 'Info message';
    const logger = new Logger(loggerLevel, id);
    console.log = jest.fn();
    logger.info(messageToPrint);
    expect(console.log).toHaveBeenCalledTimes(expectedCalledTimes);
    if (expectedCalledTimes === 1) {
      const message = id ? `${id}: ${messageToPrint}` : messageToPrint;
      expect(console.log).toHaveBeenCalledWith(message);
    }
  });

  it.each`
    loggerLevel           | id        | expectedCalledTimes
    ${LoggerLevel.None}   | ${null}   | ${1}
    ${LoggerLevel.None}   | ${'123'}  | ${1}
    ${LoggerLevel.Debug}  | ${null}   | ${1}
    ${LoggerLevel.Debug}  | ${'123'}  | ${1}
    ${LoggerLevel.Info}   | ${null}   | ${1}
    ${LoggerLevel.Info}   | ${'123'}  | ${1}
    ${LoggerLevel.Warn}   | ${null}   | ${1}
    ${LoggerLevel.Warn}   | ${'123'}  | ${1}
    ${LoggerLevel.Error}  | ${null}   | ${0}
    ${LoggerLevel.Error}  | ${'123'}  | ${0}
  `('should print to the console if LoggerLevel is equal or lesser than 3 (LoggerLevel.Warn) a message that starts with the specified id only if provided', ({ loggerLevel, id, expectedCalledTimes }) => {
    const messageToPrint = 'Warn message';
    const logger = new Logger(loggerLevel, id);
    console.warn = jest.fn();
    logger.warn(messageToPrint);
    expect(console.warn).toHaveBeenCalledTimes(expectedCalledTimes);
    if (expectedCalledTimes === 1) {
      const message = id ? `${id}: ${messageToPrint}` : messageToPrint;
      expect(console.warn).toHaveBeenCalledWith(message);
    }
  });

  it.each`
    loggerLevel           | id        | expectedCalledTimes
    ${LoggerLevel.None}   | ${null}   | ${1}
    ${LoggerLevel.None}   | ${'123'}  | ${1}
    ${LoggerLevel.Debug}  | ${null}   | ${1}
    ${LoggerLevel.Debug}  | ${'123'}  | ${1}
    ${LoggerLevel.Info}   | ${null}   | ${1}
    ${LoggerLevel.Info}   | ${'123'}  | ${1}
    ${LoggerLevel.Warn}   | ${null}   | ${1}
    ${LoggerLevel.Warn}   | ${'123'}  | ${1}
    ${LoggerLevel.Error}  | ${null}   | ${1}
    ${LoggerLevel.Error}  | ${'123'}  | ${1}
  `('should print to the console if LoggerLevel is equal or lesser than 4 (LoggerLevel.Error) a message that starts with the specified id only if provided', ({ loggerLevel, id, expectedCalledTimes }) => {
    const messageToPrint = 'Error message';
    const logger = new Logger(loggerLevel, id);
    console.error = jest.fn();
    logger.error(messageToPrint);
    expect(console.error).toHaveBeenCalledTimes(expectedCalledTimes);
    if (expectedCalledTimes === 1) {
      const message = id ? `${id}: ${messageToPrint}` : messageToPrint;
      expect(console.error).toHaveBeenCalledWith(message);
    }
  });
});