import { SocketIOSignaler } from '../src/SocketIOSignaler';

const socket = {
  id: 'socketId',
  close: jest.fn(),
  emit: jest.fn(),
  on: jest.fn(),
};
jest.mock('socket.io-client', () => {
  return jest.fn(() => socket);
});

describe('SocketIOSignaler', () => {
  let signaler: SocketIOSignaler;
  beforeEach(() => {
    jest.clearAllMocks();
    signaler = new SocketIOSignaler('signalerId', 'https://myWebSocketUrl.com');
  });

  it('should return own id', () => {
    expect(signaler.id).toBe('socketId');
  });

  it('should emit a message', () => {
    const type = 'type';
    const params = { id: 1 };
    signaler.send(type, params);
    expect(socket.emit).toHaveBeenCalledTimes(1);
    expect(socket.emit).toHaveBeenCalledWith(type, params);
  });

  it('should close the socket connection on dispose', () => {
    signaler.dispose();
    expect(socket.close).toHaveBeenCalledTimes(1);
  });
});